from .variable import *
import requests
import json

###채팅방기능

class chat:
    def all_chat_list(self,debug=False)->dict:
        ''' all_chat_list 는 모든 채팅방 리스트를 출력합니다.
        :param debug: response 출력 여부
        :return: 채팅방 목록을 최신순으로 딕셔너리 형식으로 return
        '''
        res = requests.get(f"{url}/be/api/v2/chat", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']

    def chat_list(self,limit:int,debug=False)->dict:
        '''채팅방의 리스트를 limit 개수만큼 출력합니다.
        :param limit: 출력할 채팅방의 개수
        :param debug: response 출력 여부
        :return: 채팅방 목록을 최신순으로 딕셔너리 형식으로 return
        '''
        res = requests.get(f"{url}/be/api/v2/chat?type=character&limit={limit}", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']
    def chat_log(self,room_id :str,limit:int,debug=False)->dict:
        '''해당하는 room_id의 채팅방의 채팅내역을 출력합니다.
        :param room_id: 채팅방의 id (ex. 67714607f21ad8d290923bb0)
        :param limit: 출력할 채팅방의 개수
        :param debug: response 출력 여부
        :return: 채팅내역을 최신순으로 limit 개수만큼 불러온후 return
        '''
        res = requests.get(f"{url2}/terry/api/v2/chat-room/{room_id}/messages?limit={limit}", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']
    def send(self,room_id:str,message:str,isSuperMode:bool=False,debug=False)->str:
        ''' 채팅을 보낸후 응답결과를 받습니다
        :param room_id: 채팅방의 id (ex. 67714607f21ad8d290923bb0)
        :param message: 보낼 메시지
        :param isSuperMode: 슈퍼챗 사용여부
        :param debug: response 출력 여부
        :return: 답변 내용을 str로 return
        '''
        try:
            data = {"message":message,"reroll":False,"images":[],"isSuperMode":isSuperMode}
            #채팅 보내기
            res_send = requests.post(f"{url2}/terry/characters/chat/{room_id}/message",headers=self.cookie,json=data)
            if res_send.status_code != 201 and debug is False:
                raise Exception(res_send.status_code)
            json_res = json.loads(res_send.text)
            #채팅 받기
            res_recieve = requests.get(f"{url2}/terry/characters/chat/{room_id}/message/{json_res["data"]}",headers=self.cookie).text.split("\n\n")
            output = ""
            di = []
            for i in res_recieve:
                if i != "":
                    di.append(json.loads(i.replace("data: ", "")))
            for i in di:
                try:
                    output = output + i["chunk"]
                except:
                    pass
        except Exception as e:
            if debug is False:
                print("Char Send Error")
            if debug is True:
                print(e)

        return output



from .variable import *
import requests
import json

#피드조회기능

class feed:
    def ranking(self,limit:int,period="daily",debug=False)->dict:
        '''랭킹목록을 가져옴
        :param limit: 가져올 개수
        :param period: 일간랭킹 월간랭킹 지정 (ex. daily,weekly,monthly)
        :param debug: response 출력 여부
        :return: 순위를 순위순으로 return
        '''
        res = requests.get(f"{url}/be/characters/ranking?limit={limit}&period={period}", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']

    def characters_sorted_by_likeCount(self,limit:int,debug=False)->dict:
        '''좋아요 순으로 캐릭터 가져옴
        :param limit: 가져올 캐릭터 개수
        :param debug: response 출력 여부
        :return: 종아요순으로 return
        '''
        res = requests.get(f"{url}/be/characters?limit={limit}&sort=likeCount", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']

    def characters_me_liked(self,limit:int,debug=False)->dict:
        '''내가 좋아요를 누른 캐릭터를 가져옴
        :param limit: 가져올 캐릭터 개수
        :param debug: response 출력 여부
        :return: 최신순으로 return
        '''
        res = requests.get(f"{url}/be/characters/me/liked?limit={limit}", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']


from .variable import *
import requests
import json

#챗봇제작 클레스

class charmaker:
    def make_char(self,data :dict,debug=False)->dict:
        '''챗봇만들기
        :param data: {
            "name":"테스트4",
            "description":"테스트4",
            "profileImageUrl":"<이미지url>",
            "model":"sonnet",
            "initialMessages":["테스트4"],
            "characterDetails":"테스트4",
            "situationImages":[],
            "categoryIds":["65e809f21a9eea7b2f660937"],
            "tags":[],"visibility":"public",
            "promptTemplate":"simulation",
            "isCommentBlocked":false,
            "defaultStartingSetName":"기본 설정",
            "keywordBook":[
            {
                "keywords":["테스트"],
                "prompt":"테스트4",
                "name":"키워드 노트 1"
            }
            ],
            "isAdult":false
        }
        :return: 성공여부와 echo를 return
        '''
        res = requests.post(f"{url}/be/characters",headers=self.cookie,json=data)
        if res.status_code != 201 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)

    def modify_char(self,data :dict,char_id :str,debug=False)->dict:
        '''챗봇수정
        :param data: {
            "name":"테스트6",
            "description":"테스트5",
            "profileImageUrl":"<이미지url>",
            "model":"sonnet",
            "initialMessages":["테스트5"],
            "characterDetails":"테스트5",
            "replySuggestions":["안녕 테스트5! 어떻게 지내?","테스트5, 여기서 뭐하고 있었어? 뭔가 재밌는 일이 생겼어?","오, 테스트5! 요즘 어떤 일들이 있었는지 이야기 좀 해줘, 궁금해!"],
            "chatExamples":[],
            "situationImages":[],
            "categoryIds":["65e809f21a9eea7b2f660937"],
            "tags":[],
            "visibility":"public",
            "promptTemplate":"simulation",
            "isCommentBlocked":false,
            "defaultStartingSetName":"기본 설정",
            "startingSets":[],
            "keywordBook":[{
                "keywords":["테스트"],
                "prompt":"테스트5",
                "name":"키워드 노트 1"
            }
            ]
        }
        :return: 성공여부와 echo를 retur
        '''
        res = requests.patch(f"{url}/be/characters/{char_id}", headers=self.cookie, json=data)
        if res.status_code != 201 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)


import requests


#메인 클레스
class Wrtn:
    # 유저정보클레스
    from .user import user
    # 채팅클레스
    from .chat import chat
    # 피드클레스
    from .feed import feed
    # 챗봇제작클레스
    from .charmaker import charmaker
    def refresh_token(self,refresh_token:str)->str:
        ''' refresh token을 사용해서 access token 와 토큰정지시간을 가져옴
        :param refresh_token: refresh token 타입 str
        :return: access_token, accessTokenExpiredAt 타입 str
        '''
        res = requests.post(url="https://api.wow.wrtn.ai/auth/refresh",headers={"Refresh":refresh_token})
        res_json = res.json()
        if res.status_code != 201:
            raise Exception(res.status_code)
        if res_json['result'] != "SUCCESS":
            raise Exception("Failed to refresh token")
        return res_json['data']['accessToken'],res_json['data']['accessTokenExpiredAt']
    def __init__(self,refresh_token:str)->None:
        '''refresh token 및 쿠키지정
        :param refresh_token: refresh_token 타입 str
        '''
        self.access_Token, self.accessTokenExpiredAt = self.refresh_token(refresh_token)
        self.cookie = {f"Authorization": f"Bearer {self.access_Token}"}


from .variable import *
import requests
import json

#유저정보기능

class user:
    def direct_info(self,debug=False)->dict:
        '''유저정보를 json그대로 가져옴
        :param debug: response 출력 여부
        :return: 유저 정보를 dict 형태로 return
        '''
        res = requests.put(f"{url}/be/user", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']

    def nickname(self,debug=False)->str:
        '''유저이름을 가져옴
        :param debug: response 출력 여부
        :return: 유저이름을 str로 return
        '''
        res = requests.put(f"{url}/be/user", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']['name']

    def uid(self,debug=False)->str:
        '''유저 uid를 가져옴
        :param debug: response 출력 여부
        :return: 유저uid를 str로 return
        '''
        res = requests.put(f"{url}/be/user", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']['wrtnUid']

    def _id(self,debug=False)->str:
        '''유저 _id를 가져옴
        :param debug: response 출력 여부
        :return: 유저_id를 str로 return
        '''
        res = requests.put(f"{url}/be/user", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']['_id']

    def marketingAccountTerm(self,debug=False)->str:
        '''계정생성날자를 가져옴
        :param debug: response 출력 여부
        :return: 계정생성날자를 str로 return
        '''
        res = requests.put(f"{url}/be/user", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']['marketingTerm']

    def isNewbie(self,debug=False)->bool:
        '''뉴비여부를 가져옴
        :param debug: response 출력 여부
        :return: 뉴비여부를 bool로 return
        '''
        res = requests.put(f"{url}/be/user", headers=self.cookie)
        if res.status_code != 200 and debug is False:
            raise Exception(res.status_code)
        return json.loads(res.text)['data']['isNewbie']



from setuptools import setup

# README.md 파일을 불러오는 기능
with open('README.md', encoding='utf-8') as f:
  long_description = f.read()

setup(
  name='wrtn', # 등록할 패키지 이름 (PyPI에 등록되는 이름)
  version='1.2.0', # 패키지 버전
  description='unoffical wrtn api', # 패키지의 짧은 설명
  long_description=long_description, # 패키지의 상세 설명
  long_description_content_type = 'text/markdown', # long_description의 형식
  author='sickwrtn', # 패키지 작성자 이름
  author_email='sillo154265@gmail.com', # 패키지 작성자 이메일
  url='https://github.com/sickwrtn/unoffical_wrtn_api', # 프로젝트의 공식 URL
  license='MIT', # 패키지의 라이선스 정보
  python_requires='>=3.7', # 패키지가 지원하는 Python 버전
  install_requires=["requests==2.32.3",
    "setuptools==75.6.0",], # 패키지가 의존하는 외부 라이브러리 목록
  classifiers=[
    'Development Status :: 4 - Beta',
    'Intended Audience :: Developers',
    'Programming Language :: Python :: 3',
    'Operating System :: OS Independent',
    'License :: OSI Approved :: MIT License',
  ] # 패키지 분류
)


from wrtn import Wrtn

client = Wrtn(refresh_token='<refresh_TOKEN>')

print(client.chat.chat_list(client,limit=1)['chats'][0])
print(client.chat.chat_log(client,room_id="<room_id>",limit=10)['list'][0])
print(client.chat.send(client,message="안녕",room_id="<채팅방id>",isSuperMode=False))

